#!/bin/bash

bin="/usr/bin/wget"
bin_opts="-q --content-on-error"	
diff="diff -iad"
domain="http://neptune/testing/"

usage() { 
	echo "$0 usage:";
	echo -e "\t-h : print help";
	echo -e "\t-r : Rebase";
	echo -e "\t-t : Test";
	exit 0;
}

[ $# -eq 0 ] && usage

while getopts "hrt" arg; do
  case $arg in
    #p) # Specify p value.
    #  echo "p is ${OPTARG}"
    #  ;;
    r) 
      rebase="yes"
      ;;
    t)
      rebase="no"
      ;;
    h | *)
      usage
      exit 0
      ;;
  esac
done

tests_count=0
success_count=0
for file in `ls tests/*.html`; do
	tests_count=$(($tests_count+1))
	file_in=`basename $file`
	file_out_val="base/$file_in"	   # The out file to check against
	file_out_tst="/tmp/$file_in"   # The outfile from test application

	if [ $rebase != "yes" -a ! -f "$file_out_val" ]; then
		printf "Results file %s is missing\n" "$file_out_val"
		continue;
	fi

	# Run application, redirect in file to app, and output to out file
	test_url="$domain""tests/""$file_in"
	(cd /tmp/; $bin $bin_opts "$test_url")
	e_code=$?
	if [ $e_code != 0 ]; then
		# get HTTP status code :
		http_code=`wget -t --spider -S "$test_url" 2>&1 | grep "HTTP/" | awk '{print $2}'`
		if [ $e_code != 8 -a $http_code != 500 -a $http_code != 404 -a $http_code != 403 ]; then
			printf "%-30s : \e[91mFAIL!\e[0m : %d, HTTP code %s\n" "$file_in" "$e_code" "$http_code"
			rm $file_out_tst
			continue;
		fi
	fi
	if [ $rebase == "yes" ]; then
		cp $file_out_tst $file_out_val
	fi

	# Execute diff
	$diff "$file_out_tst" "$file_out_val"

	# Check exit code from previous command (ie diff)
	# We need to add this to a variable else we can't print it
	# as it will be changed by the if [
	# Iff not 0 then the files differ (at least with diff)
	e_code=$?
	if [ $e_code != 0 ]; then
		printf "%-30s : \e[91mFAIL!\e[0m : %d\n" "$file_in" "$e_code"
	else
		success_count=$(($success_count+1))
		printf "%-30s : \e[92mOK!\e[0m\n" "$file_in"
	fi
	#clean-up
	rm $file_out_tst
done
printf "Results: [%d/%d] success!\n" "$success_count" "$tests_count"
# Clean exit with status 0
exit 0

